Displaying 20 results from an estimated 35 matches for "99,13".
Did you mean:
99,17
2019 Nov 21
0
[PATCH net-next 2/6] vsock: add VMADDR_CID_LOCAL definition
...garzare at redhat.com>
> ---
> include/uapi/linux/vm_sockets.h | 8 +++++---
> net/vmw_vsock/vmci_transport.c | 2 +-
> 2 files changed, 6 insertions(+), 4 deletions(-)
>
> diff --git a/include/uapi/linux/vm_sockets.h
> b/include/uapi/linux/vm_sockets.h
> index 68d57c5e99bc..fd0ed7221645 100644
> --- a/include/uapi/linux/vm_sockets.h
> +++ b/include/uapi/linux/vm_sockets.h
> @@ -99,11 +99,13 @@
>
> #define VMADDR_CID_HYPERVISOR 0
>
> -/* This CID is specific to VMCI and can be considered reserved (even VMCI
> - * doesn't use it anymore...
2017 Mar 20
2
[PATCH] daemon: selinux: Add setfiles -m option to suppress extra excludes (RHBZ#1433577).
...s, "-m", NULL));
+ flag = err && strstr (err, /* "invalid option -- " */ "'m'") == NULL;
+ }
+
+ return flag;
+}
+
/* Takes optional arguments, consult optargs_bitmask. */
int
do_selinux_relabel (const char *specfile, const char *path,
@@ -83,6 +99,13 @@ do_selinux_relabel (const char *specfile, const char *path,
ADD_ARG (argv, i, "-e"); ADD_ARG (argv, i, s_selinux);
ADD_ARG (argv, i, "-e"); ADD_ARG (argv, i, s_sys);
+ /* You have to use the -m option (where available) otherwise
+ * setfiles puts all the mountpo...
2013 Nov 27
2
non-standard alloca.h
...Ws/1ZLjNjQzx8f+0B
CK5tRUo0k1WlGe5oPHEuIBce3spqdeR5Npsj/A1cz5sxpwxINyAfPgjJB7QiysU=
=Zjgt
-----END PGP SIGNATURE-----
-------------- next part --------------
--- opus-1.1-beta/configure.ac.orig 2013-07-31 06:27:54.930255200 +0000
+++ opus-1.1-beta/configure.ac 2013-07-31 06:28:56.746104800 +0000
@@ -99,9 +99,13 @@
AS_IF([test "$has_var_arrays" = "no"],
[
AC_CHECK_HEADERS([alloca.h])
+ AC_CHECK_HEADERS([malloc.h])
AC_MSG_CHECKING(for alloca)
- AC_COMPILE_IFELSE([AC_LANG_PROGRAM([[#include <alloca.h>]],
+ AC_COMPILE_IFELSE([AC_LANG_PROGRAM([[#ifdef HAVE...
2003 Sep 16
5
OpenSSH Security Advisory: buffer.adv
...ieving revision 1.16
retrieving revision 1.17
diff -u -r1.16 -r1.17
--- buffer.c 26 Jun 2002 08:54:18 -0000 1.16
+++ buffer.c 16 Sep 2003 03:03:47 -0000 1.17
@@ -69,6 +69,7 @@
void *
buffer_append_space(Buffer *buffer, u_int len)
{
+ u_int newlen;
void *p;
if (len > 0x100000)
@@ -98,11 +99,13 @@
goto restart;
}
/* Increase the size of the buffer and retry. */
- buffer->alloc += len + 32768;
- if (buffer->alloc > 0xa00000)
+
+ newlen = buffer->alloc + len + 32768;
+ if (newlen > 0xa00000)
fatal("buffer_append_space: alloc %u not supported",
- b...
2013 Jun 04
1
[PATCH] add restricted mode to sftp-server
Hello.
These patches add a new mode of operation for the sftp server.
It is located between the ordinary, unrestricted mode and read-only mode.
It allows you to add files to the server, but only if these files do
not exist on the server before.
Changes to existing files - are prohibited.
Please review them, maybe these patches will be useful not only to me.
Thank you.
-------------- next part
2003 Sep 16
1
OpenSSH Security Advisory: buffer.adv
...ieving revision 1.16
retrieving revision 1.17
diff --git a/arch/x86/Makefile b/arch/x86/Makefile
index 75ef499..85a66c4 100644
--- a/arch/x86/Makefile
+++ b/arch/x86/Makefile
@@ -232,13 +232,6 @@ archscripts: scripts_basic
archheaders:
$(Q)$(MAKE) $(build)=arch/x86/entry/syscalls all
-archmacros:
- $(Q)$(MAKE) $(build)=arch/x86/kernel arch/x86/kernel/macros.s
-
-ASM_MACRO_FLAGS = -Wa,arch/x86/kernel/ma...
2020 Feb 25
6
[PATCH nbdkit 0/5] server: Add .get_ready callback.
I like this change. I think we were overloading the config_complete
method before to do two different things (complete configuration; do
any allocation/housekeeping necessary before we can start serving).
The only questions in my mind are whether we want this before 1.18,
and whether the name ("get_ready") is a good one.
Rich.
2018 Dec 13
2
[PATCH] kbuild, x86: revert macros in extended asm workarounds
...bugs")
- 0474d5d9d2f7f3b11262f7bf87d0e7314ead9200.
("x86/extable: Macrofy inline assembly code to work around GCC inlining bugs")
- 494b5168f2de009eb80f198f668da374295098dd.
("x86/paravirt: Work around GCC inlining bugs when compiling paravirt ops")
- f81f8ad56fd1c7b99b2ed1c314527f7d9ac447c6.
("x86/bug: Macrofy the BUG table section handling, to work around GCC inlining bugs")
- 77f48ec28e4ccff94d2e5f4260a83ac27a7f3099.
("x86/alternatives: Macrofy lock prefixes to work around GCC inlining bugs")
- 9e1725b410594911cc5981b6c7b4cea4ec054ca8...
2018 Dec 13
2
[PATCH] kbuild, x86: revert macros in extended asm workarounds
...bugs")
- 0474d5d9d2f7f3b11262f7bf87d0e7314ead9200.
("x86/extable: Macrofy inline assembly code to work around GCC inlining bugs")
- 494b5168f2de009eb80f198f668da374295098dd.
("x86/paravirt: Work around GCC inlining bugs when compiling paravirt ops")
- f81f8ad56fd1c7b99b2ed1c314527f7d9ac447c6.
("x86/bug: Macrofy the BUG table section handling, to work around GCC inlining bugs")
- 77f48ec28e4ccff94d2e5f4260a83ac27a7f3099.
("x86/alternatives: Macrofy lock prefixes to work around GCC inlining bugs")
- 9e1725b410594911cc5981b6c7b4cea4ec054ca8...
2018 May 15
12
[PATCH libldm 00/12] New API: an ability to retrieve created device-mapper devices back after they have been created.
The main goal of these patch series is to implement a new API that allows to retrieve created device-mapper devices for volumes and partitions back after they have been created.
As part of this patch:
- required libdevmapper version was bumped to 1.02. I think it is safe because it was released more then 10 years ago;
- newer version of libdevmapper allowed to simplify code base a little bit;
-
diff -u -r1.16 -r1.17
--- buffer.c 26 Jun 2002 08:54:18 -0000 1.16
+++ buffer.c 16 Sep 2003 03:03:47 -0000 1.17
@@ -69,6 +69,7 @@
void *
buffer_append_space(Buffer *buffer, u_int len)
{
+ u_int newlen;
void *p;
if (len > 0x100000)
@@ -98,11 +99,13 @@
goto restart;
}
/* Increase the size of the buffer and retry. */
- buffer->alloc += len + 32768;
- if (buffer->alloc > 0xa00000)
+
+ newlen = buffer->alloc + len + 32768;
+ if (newlen > 0xa00000)
fatal("buffer_append_space: alloc %u not supported",
- b...
2013 Jan 22
5
[QEMU PATCH v5 0/3] virtio-net: fix of ctrl commands
Currently virtio-net code relys on the layout of descriptor,
this patchset removed the assumptions and introduced a control
command to set mac address. Last patch is a trivial renaming.
V2: check guest's iov_len
V3: fix of migration compatibility
make mac field in config space read-only when new feature is acked
V4: add fix of descriptor layout assumptions, trivial rename
V5: fix
2013 Jan 22
5
[QEMU PATCH v5 0/3] virtio-net: fix of ctrl commands
Currently virtio-net code relys on the layout of descriptor,
this patchset removed the assumptions and introduced a control
command to set mac address. Last patch is a trivial renaming.
V2: check guest's iov_len
V3: fix of migration compatibility
make mac field in config space read-only when new feature is acked
V4: add fix of descriptor layout assumptions, trivial rename
V5: fix
2013 Jan 19
8
[QEMU PATCH v4 0/3] virtio-net: fix of ctrl commands
From: Amos Kong <akong at redhat.com>
Currently virtio-net code relys on the layout of descriptor,
this patchset removed the assumptions and introduced a control
command to set mac address. Last patch is a trivial renaming.
V2: check guest's iov_len
V3: fix of migration compatibility
make mac field in config space read-only when new feature is acked
V4: add fix of descriptor layout
2013 Jan 19
8
[QEMU PATCH v4 0/3] virtio-net: fix of ctrl commands
From: Amos Kong <akong at redhat.com>
Currently virtio-net code relys on the layout of descriptor,
this patchset removed the assumptions and introduced a control
command to set mac address. Last patch is a trivial renaming.
V2: check guest's iov_len
V3: fix of migration compatibility
make mac field in config space read-only when new feature is acked
V4: add fix of descriptor layout
2008 Mar 29
0
GCC/ELF Visibility patch
...ts)
{
if (bits->owner)
speex_free(bits->chars);
/* Will do something once the allocation is dynamic */
}
-void speex_bits_reset(SpeexBits *bits)
+EXPORT void speex_bits_reset(SpeexBits *bits)
{
/* We only need to clear the first byte now */
bits->chars[0]=0;
@@ -99,14 +99,14 @@
bits->overflow=0;
}
-void speex_bits_rewind(SpeexBits *bits)
+EXPORT void speex_bits_rewind(SpeexBits *bits)
{
bits->charPtr=0;
bits->bitPtr=0;
bits->overflow=0;
}
-void speex_bits_read_from(SpeexBits *bits, char *chars, int len)
+EXPORT void speex_bi...
2008 Mar 29
2
GCC/ELF Visibility patch (fwd)
...ts)
{
if (bits->owner)
speex_free(bits->chars);
/* Will do something once the allocation is dynamic */
}
-void speex_bits_reset(SpeexBits *bits)
+EXPORT void speex_bits_reset(SpeexBits *bits)
{
/* We only need to clear the first byte now */
bits->chars[0]=0;
@@ -99,14 +99,14 @@
bits->overflow=0;
}
-void speex_bits_rewind(SpeexBits *bits)
+EXPORT void speex_bits_rewind(SpeexBits *bits)
{
bits->charPtr=0;
bits->bitPtr=0;
bits->overflow=0;
}
-void speex_bits_read_from(SpeexBits *bits, char *chars, int len)
+EXPORT void speex_bi...
2012 Aug 13
2
[PATCH] Replace hard-coded PKG_STATEDIR with state_dir setting
...settings->state_dir, "/instances", NULL);
+ list = master_instance_list_init(instance_path);
iter = master_instance_list_iterate_init(list);
while ((inst = master_instance_iterate_list_next(iter)) != NULL) {
if (argv[0] != NULL && strcmp(argv[0], inst->name) != 0)
@@ -99,13 +100,14 @@
{
struct master_instance_list *list;
const struct master_instance *inst;
- const char *base_dir;
+ const char *base_dir, *instance_path;
int ret;
if (argc != 2)
instance_cmd_help(cmd_instance_remove);
- list = master_instance_list_init(MASTER_INSTANCE_PATH);
+ instance...
2019 Dec 10
7
[PATCH net-next v2 0/6] vsock: add local transport support
v2:
- style fixes [Dave]
- removed RCU sync and changed 'the_vsock_loopback' in a global
static variable [Stefan]
- use G2H transport when local transport is not loaded and remote cid
is VMADDR_CID_LOCAL [Stefan]
- rebased on net-next
v1: https://patchwork.kernel.org/cover/11251735/
This series introduces a new transport (vsock_loopback) to handle
local communication.
This
2020 Sep 21
0
[nbdkit PATCH v3 06/14] api: Add .export_description
...assert False
-except nbd.Error as ex:
- pass
+must_fail(h.get_canonical_export_name)
+must_fail(h.get_export_description)
h.shutdown()
'
# With client request, reflect the export name back
nbdsh -c '
import os
@@ -99,13 +96,16 @@ h.connect_unix(os.environ["sock"])
h.set_export_name("a")
h.opt_info()
assert h.get_canonical_export_name() == "a"
+assert h.get_export_description() == "a world"
h.set_export_name("")
h.opt_info()
assert h.get_canonical_export_n...
2018 Dec 16
1
[PATCH v2] x86, kbuild: revert macrofying inline assembly code
...,6 @@ archheaders:
PHONY += archscripts
archscripts:
-PHONY += archmacros
-archmacros:
-
PHONY += __headers
__headers: $(version_h) scripts_basic uapi-asm-generic archheaders archscripts
$(Q)$(MAKE) $(build)=scripts build_unifdef
@@ -99,13 +100,14 @@
h.shutdown()
'
-# With client request, reflect the export name back
+# With client request, reflect the export name and description back
nbdsh -c '
import os